@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-from ocp_resources.constants import TIMEOUT_4MINUTES
-from ocp_resources.logger import get_logger
+import logging
+
 from ocp_resources.persistent_volume_claim import PersistentVolumeClaim
-from ocp_resources.resource import NamespacedResource, Resource
-from ocp_resources.utils import TimeoutExpiredError, TimeoutSampler
+from ocp_resources.resource import TIMEOUT, NamespacedResource, Resource
 
 
-LOGGER = get_logger(name=__name__)
+LOGGER = logging.getLogger(__name__)
 
 
 class DataVolume(NamespacedResource):
@@ -30,7 +29,6 @@ class DataVolume(NamespacedResource):
         SMART_CLONE_PVC_IN_PROGRESS = "SmartClonePVCInProgress"
         UPLOAD_READY = "UploadReady"
         UNKNOWN = "Unknown"
-        WAIT_FOR_FIRST_CONSUMER = "WaitForFirstConsumer"
 
     class AccessMode:
         """
@@ -68,18 +66,18 @@ class DataVolume(NamespacedResource):
 
     def __init__(
         self,
-        name=None,
-        namespace=None,
+        name,
+        namespace,
         source=None,
         size=None,
         storage_class=None,
         url=None,
         content_type=ContentType.KUBEVIRT,
-        access_modes=None,
+        access_modes=AccessMode.RWO,
         cert_configmap=None,
         secret=None,
         client=None,
-        volume_mode=None,
+        volume_mode=VolumeMode.FILE,
         hostpath_node=None,
         source_pvc=None,
         source_namespace=None,
@@ -88,9 +86,6 @@ class DataVolume(NamespacedResource):
         preallocation=None,
         teardown=True,
         privileged_client=None,
-        yaml_file=None,
-        delete_timeout=TIMEOUT_4MINUTES,
-        api_name="pvc",
     ):
         super().__init__(
             name=name,
@@ -98,8 +93,6 @@ class DataVolume(NamespacedResource):
             client=client,
             teardown=teardown,
             privileged_client=privileged_client,
-            yaml_file=yaml_file,
-            delete_timeout=delete_timeout,
         )
         self.source = source
         self.url = url
@@ -116,32 +109,28 @@ class DataVolume(NamespacedResource):
         self.multus_annotation = multus_annotation
         self.bind_immediate_annotation = bind_immediate_annotation
         self.preallocation = preallocation
-        self.api_name = api_name
 
     def to_dict(self):
         res = super().to_dict()
-        if self.yaml_file:
-            return res
         res.update(
             {
                 "spec": {
                     "source": {self.source: {"url": self.url}},
-                    self.api_name: {
+                    "pvc": {
+                        "accessModes": [self.access_modes],
                         "resources": {"requests": {"storage": self.size}},
                     },
                 }
             }
         )
-        if self.access_modes:
-            res["spec"][self.api_name]["accessModes"] = [self.access_modes]
         if self.content_type:
             res["spec"]["contentType"] = self.content_type
         if self.storage_class:
-            res["spec"][self.api_name]["storageClassName"] = self.storage_class
+            res["spec"]["pvc"]["storageClassName"] = self.storage_class
         if self.secret:
             res["spec"]["source"][self.source]["secretRef"] = self.secret.name
         if self.volume_mode:
-            res["spec"][self.api_name]["volumeMode"] = self.volume_mode
+            res["spec"]["pvc"]["volumeMode"] = self.volume_mode
         if self.source == "http" or "registry":
             res["spec"]["source"][self.source]["url"] = self.url
         if self.cert_configmap:
@@ -176,7 +165,7 @@ class DataVolume(NamespacedResource):
 
         return res
 
-    def wait_deleted(self, timeout=TIMEOUT_4MINUTES):
+    def wait_deleted(self, timeout=TIMEOUT):
         """
         Wait until DataVolume and the PVC created by it are deleted
 
@@ -189,10 +178,7 @@ class DataVolume(NamespacedResource):
         super().wait_deleted(timeout=timeout)
         return self.pvc.wait_deleted(timeout=timeout)
 
-    def wait(self, timeout=600, failure_timeout=120):
-        self._check_none_pending_status(failure_timeout=failure_timeout)
-
-        # If DV's status is not Pending, continue with the flow
+    def wait(self, timeout=600):
         self.wait_for_status(status=self.Status.SUCCEEDED, timeout=timeout)
         self.pvc.wait_for_status(
             status=PersistentVolumeClaim.Status.BOUND, timeout=timeout
@@ -213,21 +199,3 @@ class DataVolume(NamespacedResource):
             namespace=self.namespace,
             client=self.client,
         )
-
-    def _check_none_pending_status(self, failure_timeout=120):
-        # Avoid waiting for "Succeeded" status if DV's in Pending/None status
-        sample = None
-        try:
-            for sample in TimeoutSampler(
-                wait_timeout=failure_timeout,
-                sleep=10,
-                func=lambda: self.instance.status.phase,
-            ):
-                # If DV status is Pending (or Status is not yet updated) continue to wait, else exit the wait loop
-                if sample in [self.Status.PENDING, None]:
-                    continue
-                else:
-                    break
-        except TimeoutExpiredError:
-            LOGGER.error(f"{self.name} status is {sample}")
-            raise
